Home
last modified time | relevance | path

Searched refs:out2 (Results 1 – 25 of 150) sorted by relevance

123456

/llvm-project/clang/test/CodeGen/
H A Dasm-goto.c39 int test3(int out1, int out2) { in test3() argument
44 …asm volatile goto("testl %0, %0; jne %l3;" : "=r"(out1), "=r"(out2) : "r"(out1) :: label_true, loo… in test3()
45 …asm volatile goto("testl %0, %0; jne %l4;" : "=r"(out1), "=r"(out2) : "r"(out1) :: label_true, loo… in test3()
56 int test4(int out1, int out2) { in test4() argument
61 if (out1 < out2) in test4()
62 asm volatile goto("jne %l5" : "+S"(out1), "+D"(out2) : "r"(out1) :: label_true, loop); in test4()
64 … asm volatile goto("jne %l7" : "+S"(out1), "+D"(out2) : "r"(out1), "r"(out2) :: label_true, loop); in test4()
68 return out1 + out2; in test4()
99 int out2 = 42; in test6() local
100 …asm volatile goto("testl %0, %0; testl %1, %1; jne %l3" : "+S"(out2) : "r"(out1) :: label_true, la… in test6()
[all …]
H A Dvoidptr-vaarg.c312 void multiple_int(__builtin_va_list list, int *out0, int *out1, int *out2) { in multiple_int()
315 *out2 = __builtin_va_arg(list, int); in multiple_int()
358 one_short_t *out1, int *out2, double *out3) { in increasing_alignment()
361 *out2 = __builtin_va_arg(list, int); in increasing_alignment()
404 one_short_t *out2, one_char_t *out3) { in decreasing_alignment()
407 *out2 = __builtin_va_arg(list, one_short_t); in decreasing_alignment()
311 multiple_int(__builtin_va_list list,int * out0,int * out1,int * out2) multiple_int() argument
357 increasing_alignment(__builtin_va_list list,one_char_t * out0,one_short_t * out1,int * out2,double * out3) increasing_alignment() argument
403 decreasing_alignment(__builtin_va_list list,double * out0,int * out1,one_short_t * out2,one_char_t * out3) decreasing_alignment() argument
/llvm-project/llvm/test/Analysis/CostModel/X86/
H A Dinterleaved-store-i8-stride-3.ll
H A Dinterleaved-store-i16-stride-3.ll
H A Dinterleaved-store-f32-stride-3.ll
H A Dinterleaved-store-i32-stride-3.ll
H A Dinterleaved-store-f64-stride-3.ll
H A Dinterleaved-store-i64-stride-3.ll
/llvm-project/libcxx/test/std/algorithms/alg.modifying.operations/alg.partitions/
H A Dranges_partition_copy.pass.cpp132 std::array<int, N3> out2; in test_one() local
135 Iter(begin), Sent(Iter(end)), OutIter1(out1.data()), OutIter2(out2.data()), pred); in test_one()
139 assert(base(result.out2) == out2.data() + expected_false.size()); in test_one()
142 assert(std::ranges::equal(out2, expected_false)); in test_one()
148 std::array<int, N3> out2; in test_one() local
151 range, OutIter1(out1.data()), OutIter2(out2.data()), pred); in test_one()
155 assert(base(result.out2) == out2.data() + expected_false.size()); in test_one()
158 assert(std::ranges::equal(out2, expected_false)); in test_one()
240 std::array<int, 3> out1, out2; in test() local
241 std::ranges::partition_copy(in.begin(), in.end(), out1.begin(), out2.begin(), is_negative); in test()
[all …]
/llvm-project/clang/test/CodeGenCUDA/
H A Ddevice-use-host-var.cu85 __device__ void dev_fun(int *out, const int **out2) { in dev_fun() argument
94 *out2 = &constexpr_var; in dev_fun()
95 *out2 = &constexpr_struct.x; in dev_fun()
96 *out2 = &constexpr_array[3].x; in dev_fun()
97 *out2 = &const_var; in dev_fun()
98 *out2 = &const_struct.x; in dev_fun()
99 *out2 = &const_array[3].x; in dev_fun()
/llvm-project/llvm/test/CodeGen/Thumb2/
H A Dmve-vmull.ll14 %out2 = sext <2 x i32> %shuf2 to <2 x i64>
15 %out = mul <2 x i64> %out1, %out2
29 %out2 = sext <2 x i32> %shuf2 to <2 x i64>
30 %out = mul <2 x i64> %out1, %out2
44 %out2 = zext <2 x i32> %shuf2 to <2 x i64>
45 %out = mul <2 x i64> %out1, %out2
59 %out2 = zext <2 x i32> %shuf2 to <2 x i64>
60 %out = mul <2 x i64> %out1, %out2
74 %out2 = sext <4 x i16> %shuf2 to <4 x i32>
75 %out = mul <4 x i32> %out1, %out2
[all …]
H A Dmve-vmull-splat.ll16 %out2 = sext <2 x i32> %shuf2 to <2 x i64>
17 %out = mul <2 x i64> %out1, %out2
33 %out2 = sext <2 x i32> %shuf2 to <2 x i64>
34 %out = mul <2 x i64> %out2, %out1
108 %out2 = sext <2 x i32> %shuf2 to <2 x i64>
109 %out = mul <2 x i64> %out1, %out2
125 %out2 = sext <2 x i32> %shuf2 to <2 x i64>
126 %out = mul <2 x i64> %out2, %out1
210 %out2 = sext <4 x i32> %shuf2 to <4 x i64>
211 %out = mul <4 x i64> %out1, %out2
[all …]
/llvm-project/llvm/test/CodeGen/AMDGPU/
H A Dextract-vector-elt-build-vector-combine.ll18 ptr addrspace(1) noalias %out2,
38 store volatile i32 %extract0, ptr addrspace(1) %out2
39 store volatile i32 %extract1, ptr addrspace(1) %out2
40 store volatile i32 %extract2, ptr addrspace(1) %out2
41 store volatile i32 %extract3, ptr addrspace(1) %out2
60 ptr addrspace(1) noalias %out2,
84 store volatile i32 %op0, ptr addrspace(1) %out2
85 store volatile i32 %op1, ptr addrspace(1) %out2
86 store volatile i32 %op2, ptr addrspace(1) %out2
87 store volatile i32 %op3, ptr addrspace(1) %out2
[all …]
H A Dwmma_multiple_64.ll23 define amdgpu_ps void @test_wmma_f32_16x16x16_f16(<16 x half> %A, <16 x half> %B, <4 x float> %C, ptr addrspace(1) %out, ptr addrspace(1) %out2) {
35 store <4 x float> %res2, ptr addrspace(1) %out2, align 16
41 define amdgpu_ps void @test_wmma_f32_16x16x16_bf16(<16 x i16> %A, <16 x i16> %B, <4 x float> %C, ptr addrspace(1) %out, ptr addrspace(1) %out2) {
53 store <4 x float> %res2, ptr addrspace(1) %out2, align 16
59 define amdgpu_ps void @test_wmma_f16_16x16x16_f16_lo(<16 x half> %A, <16 x half> %B, <8 x half> %C, ptr addrspace(1) %out, ptr addrspace(1) %out2) {
71 store <8 x half> %res2, ptr addrspace(1) %out2, align 16
75 define amdgpu_ps void @test_wmma_f16_16x16x16_f16_hi(<16 x half> %A, <16 x half> %B, <8 x half> %C, ptr addrspace(1) %out, ptr addrspace(1) %out2) {
87 store <8 x half> %res2, ptr addrspace(1) %out2, align 16
93 define amdgpu_ps void @test_wmma_bf16_16x16x16_bf16_lo(<16 x i16> %A, <16 x i16> %B, <8 x i16> %C, ptr addrspace(1) %out, ptr addrspace(1) %out2) {
105 store <8 x i16> %res2, ptr addrspace(1) %out2, alig
[all...]
H A Dwmma_multiple_32.ll23 define amdgpu_ps void @test_wmma_f32_16x16x16_f16(<16 x half> %A, <16 x half> %B, <8 x float> %C, ptr addrspace(1) %out, ptr addrspace(1) %out2) {
39 store <8 x float> %res2, ptr addrspace(1) %out2, align 32
45 define amdgpu_ps void @test_wmma_f32_16x16x16_bf16(<16 x i16> %A, <16 x i16> %B, <8 x float> %C, ptr addrspace(1) %out, ptr addrspace(1) %out2) {
61 store <8 x float> %res2, ptr addrspace(1) %out2, align 32
67 define amdgpu_ps void @test_wmma_f16_16x16x16_f16_lo(<16 x half> %A, <16 x half> %B, <16 x half> %C, ptr addrspace(1) %out, ptr addrspace(1) %out2) {
83 store <16 x half> %res2, ptr addrspace(1) %out2, align 32
87 define amdgpu_ps void @test_wmma_f16_16x16x16_f16_hi(<16 x half> %A, <16 x half> %B, <16 x half> %C, ptr addrspace(1) %out, ptr addrspace(1) %out2) {
103 store <16 x half> %res2, ptr addrspace(1) %out2, align 32
109 define amdgpu_ps void @test_wmma_bf16_16x16x16_bf16_lo(<16 x i16> %A, <16 x i16> %B, <16 x i16> %C, ptr addrspace(1) %out, ptr addrspace(1) %out2) {
125 store <16 x i16> %res2, ptr addrspace(1) %out2, alig
[all...]
/llvm-project/libcxx/test/std/input.output/syncstream/osyncstream/
H A Dassign.pass.cpp49 OS out2{&base2, Allocator{99}}; in test() local
51 out2 << CharT('Z'); in test()
57 out2 = std::move(out1); in test()
64 assert(out2.get_wrapped() == &base1); in test()
66 typename OS::syncbuf_type* sb2 = out2.rdbuf(); in test()
77 out2 << CharT('B'); in test()
/llvm-project/libcxx/test/std/algorithms/
H A Dranges_robust_against_differing_projections.pass.cpp49 auto out2 = output2.begin(); in test_all() local
69 test(std::ranges::transform, in, in2, out2, sum, proj1, proj2); in test_all()
72 test(std::ranges::merge, in, in2, out2, less, proj1, proj2); in test_all()
74 test(std::ranges::set_intersection, in, in2, out2, less, proj1, proj2); in test_all()
76 test(std::ranges::set_difference, in, in2, out2, less, proj1, proj2); in test_all()
78 test(std::ranges::set_symmetric_difference, in, in2, out2, less, proj1, proj2); in test_all()
80 test(std::ranges::set_union, in, in2, out2, less, proj1, proj2); in test_all()
/llvm-project/lld/test/COFF/
H A Dout.test5 # RUN: cp %t.obj %T/out/tmp/out2
9 # RUN: rm -f out1.exe out2.exe out3.exe out3.dll out4.exe
11 # RUN: lld-link /entry:main %T/out/tmp/out2
16 # RUN: llvm-readobj out2.exe | FileCheck %s
/llvm-project/polly/lib/External/isl/
H A Disl_multi_product_templ.c27 isl_size in1, in2, out1, out2; in MULTI() local
33 out2 = FN(MULTI(BASE),dim)(multi2, isl_dim_out); in MULTI()
34 if (in1 < 0 || in2 < 0 || out1 < 0 || out2 < 0) in MULTI()
48 for (i = 0; i < out2; ++i) { in MULTI()
/llvm-project/libcxx/include/__algorithm/
H A Din_out_out_result.h33 _LIBCPP_NO_UNIQUE_ADDRESS _OutIter2 out2; member
39 return {in, out1, out2}; in in_out_out_result()
46 return {std::move(in), std::move(out1), std::move(out2)}; in in_out_out_result()
/llvm-project/llvm/test/TableGen/
H A DGlobalISelEmitter-multiple-output-discard.td
/llvm-project/clang/test/SemaOpenCL/
H A Dbuiltins-amdgcn-gfx11.cl7 void test(global uint* out1, global ulong* out2, int x) {
9 …*out2 = __builtin_amdgcn_s_sendmsg_rtnl(0); // GFX10-error {{'__builtin_amdgcn_s_sendmsg_rtnl' nee…
14 …*out2 = __builtin_amdgcn_s_sendmsg_rtnl(x); // GFX11-error {{argument to '__builtin_amdgcn_s_sendm…
/llvm-project/libcxx/test/std/algorithms/algorithms.results/
H A Din_out_out_result.pass.cpp73 assert(res.out2 == 1.f); in test()
77 assert(res2.out2.content == 1.f); in test()
91 auto [in, out1, out2] = std::ranges::in_out_out_result<int, int, int>{1, 2, 3}; in test()
94 assert(out2 == 3); in test()
/llvm-project/clang-tools-extra/test/clang-tidy/checkers/bugprone/
H A Dbranch-clone.cpp272 void test_macro7(int in, int &out1, int &out2) { in test_macro7() argument
280 void test_macro8(int in, int &out1, int &out2) { in test_macro8() argument
281 COND_INCR(in, out1, out2); in test_macro8()
284 void test_macro9(int in, int &out1, int &out2) { in test_macro9() argument
285 COND_INCR(in, out2, out2); in test_macro9()
/llvm-project/llvm/test/Linker/
H A D2004-02-17-WeakStrongLinkage.ll1 ; RUN: llvm-as < %s > %t.out2.bc
3 ; RUN: llvm-link %t.out1.bc %t.out2.bc -o /dev/null

123456